#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

import djactasauth

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = djactasauth.__version__

if sys.argv[-1] == 'publish':
    os.system('make release')
    sys.exit()

setup(
    name='djactasauth',
    version=version,
    author='Paessler AG',
    url='https://github.com/PaesslerAG/django-act-as-auth',
    packages=[
        'djactasauth',
    ],
    include_package_data=True,
    install_requires=[
        'Django>=1.5',
    ],
    license="BSD",
    zip_safe=False,
    keywords='django, authentication, act as, impersonation',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
